==> CloudClientStandardAWS_v2.0.1.zip: com/clustercontrol/ws/cloud/InstanceStateKind.java <==

package com.clustercontrol.ws.cloud;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>instanceStateKindJavaNXB
 * 
 * <p>̃XL[}EtOǵÃNXɊ܂܂\Recw肵܂B
 * <p>
 * <pre>
 * &lt;simpleType name="instanceStateKind">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="pending"/>
 *     &lt;enumeration value="running"/>
 *     &lt;enumeration value="shutting_down"/>
 *     &lt;enumeration value="terminated"/>
 *     &lt;enumeration value="stopping"/>
 *     &lt;enumeration value="stopped"/>
 *     &lt;enumeration value="rebooting"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "instanceStateKind")
@XmlEnum
public enum InstanceStateKind {

    @XmlEnumValue("pending")
    PENDING("pending"),
    @XmlEnumValue("running")
    RUNNING("running"),
    @XmlEnumValue("shutting_down")
    SHUTTING_DOWN("shutting_down"),
    @XmlEnumValue("terminated")
    TERMINATED("terminated"),
    @XmlEnumValue("stopping")
    STOPPING("stopping"),
    @XmlEnumValue("stopped")
    STOPPED("stopped"),
    @XmlEnumValue("rebooting")
    REBOOTING("rebooting");
    private final String value;

    InstanceStateKind(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static InstanceStateKind fromValue(String v) {
        for (InstanceStateKind c: InstanceStateKind.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> CloudClientStandardAWS_v2.0.3.zip: com/clustercontrol/ws/cloud/InstanceStateKind.java <==

package com.clustercontrol.ws.cloud;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>instanceStateKindのJavaクラス。
 * 
 * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
 * <p>
 * <pre>
 * &lt;simpleType name="instanceStateKind">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="pending"/>
 *     &lt;enumeration value="running"/>
 *     &lt;enumeration value="shutting_down"/>
 *     &lt;enumeration value="terminated"/>
 *     &lt;enumeration value="stopping"/>
 *     &lt;enumeration value="stopped"/>
 *     &lt;enumeration value="rebooting"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "instanceStateKind")
@XmlEnum
public enum InstanceStateKind {

    @XmlEnumValue("pending")
    PENDING("pending"),
    @XmlEnumValue("running")
    RUNNING("running"),
    @XmlEnumValue("shutting_down")
    SHUTTING_DOWN("shutting_down"),
    @XmlEnumValue("terminated")
    TERMINATED("terminated"),
    @XmlEnumValue("stopping")
    STOPPING("stopping"),
    @XmlEnumValue("stopped")
    STOPPED("stopped"),
    @XmlEnumValue("rebooting")
    REBOOTING("rebooting");
    private final String value;

    InstanceStateKind(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static InstanceStateKind fromValue(String v) {
        for (InstanceStateKind c: InstanceStateKind.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
